/* /////////////////////////////////////////////////////////////////////////////
 * File:    unistd.c
 *
 * Purpose: Definition of the chdir() and other API functions for the Win32 platform.
 *
 * Created  1st November 2003
 * Updated: 28th June 2004
 *
 * Home:    http://synesis.com.au/software/
 *
 * Copyright (c) 2002-2004, Matthew Wilson and Synesis Software
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - Neither the names of Matthew Wilson and Synesis Software nor the names of
 *   any contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * ////////////////////////////////////////////////////////////////////////// */


#define _SYNSOFT_VER_C_UNISTD_MAJOR       2
#define _SYNSOFT_VER_C_UNISTD_MINOR       0
#define _SYNSOFT_VER_C_UNISTD_REVISION    1
#define _SYNSOFT_VER_C_UNISTD_EDIT        10

#include <windows.h>
#include <errno.h>
#include <limits.h>

#include "unistd.h"

/* /////////////////////////////////////////////////////////////////////////////
 * Feature support
 */

#if defined(__BORLANDC__)
# define UNIXEM_chdir_PROVIDED_BY_COMPILER
# define UNIXEM_getcwd_PROVIDED_BY_COMPILER
#elif defined(__DMC__)
# define UNIXEM_chdir_PROVIDED_BY_COMPILER
# define UNIXEM_getcwd_PROVIDED_BY_COMPILER
#elif defined(__GNUC__)
# define UNIXEM_chdir_PROVIDED_BY_COMPILER
# define UNIXEM_getcwd_PROVIDED_BY_COMPILER
#elif defined(__INTEL_COMPILER)
#elif defined(_MSC_VER)
#elif defined(__MWERKS__)
#elif defined(__WATCOMC__)
# define UNIXEM_chdir_PROVIDED_BY_COMPILER
# define UNIXEM_getcwd_PROVIDED_BY_COMPILER
#else
# error Compiler not discriminated
#endif /* compiler */

/* /////////////////////////////////////////////////////////////////////////////
 * API functions
 */

#ifndef UNIXEM_chdir_PROVIDED_BY_COMPILER
int chdir(char const *dirName)
{
    if(SetCurrentDirectoryA(dirName))
    {
        return 0;
    }
    else
    {
        errno = ENOENT;

        return -1;
    }
}
#endif /* !UNIXEM_chdir_PROVIDED_BY_COMPILER */

#ifndef UNIXEM_getcwd_PROVIDED_BY_COMPILER
char *getcwd(char *buffer, size_t max_len)
{
    if(GetCurrentDirectoryA(max_len, buffer))
    {
        return buffer;
    }
    else
    {
        errno = ERANGE;

        return NULL;
    }
}
#endif /* !UNIXEM_getcwd_PROVIDED_BY_COMPILER */

#ifndef UNIXEM_getpagesize_PROVIDED_BY_COMPILER
int getpagesize(void)
{
    SYSTEM_INFO sysinfo;

    GetSystemInfo(&sysinfo);

    return sysinfo.dwPageSize;
}
#endif /* !UNIXEM_getpagesize_PROVIDED_BY_COMPILER */

#ifndef UNIXEM_pathconf_PROVIDED_BY_COMPILER
long pathconf(char *path, int name)
{
    ((void)path);

    switch(name)
    {
        default:
            return 0;
        case    _PC_LINK_MAX:   return LONG_MAX;
        case    _PC_MAX_CANON:  return LONG_MAX;
        case    _PC_MAX_INPUT:  return LONG_MAX;
        case    _PC_NAME_MAX:   return _MAX_FNAME;
        case    _PC_PATH_MAX:   return _MAX_PATH;
    }
}
#endif /* !UNIXEM_pathconf_PROVIDED_BY_COMPILER */


/* ////////////////////////////////////////////////////////////////////////// */
